# 中转站

:::{card} SwinFusion
:link: https://github.com/Linfeng-Tang/SwinFusion

SwinFusion（[知乎](https://zhuanlan.zhihu.com/p/401661320)）：Transformer架构(Swin Transformer)，其利用滑动窗口和分层结构使得Swin Transformer成为了机器视觉领域新的Backbone，在图像分类、目标检测、语义分割等多种机器视觉任务中达到了SOTA水平。
:::

:::{card} KuiperInfer
:link: https://github.com/zjhellofss/KuiperInfer

从零自制深度学习推理框架（[B 站](https://space.bilibili.com/1822828582)）。
:::

:::{card} Stable-Diffusion-NCNN
:link: https://github.com/EdVince/Stable-Diffusion-NCNN

Stable Diffusion in NCNN with c++
:::

:::{card} 在Android手機跑Stable Diffusion
:link: https://ivonblog.com/posts/android-stable-diffusion/
如何在Android手機Termux跑Stable Diffusion，用於AI繪圖

更多见：[ivonblog](https://ivonblog.com/)
:::

:::{card} 安卓手机「跑」Stable Diffusion创新纪录，15秒内出图
:link: https://zhuanlan.zhihu.com/p/609112801

安卓手机「跑」Stable Diffusion创新纪录，15秒内出图
:::

:::{card} 机器学习系统：设计和实现
:link: https://openmlsys.github.io/

做世界上第一本全面讲述机器学习系统知识的开源书籍
:::

:::{card} 微软人工智能教育与学习共建社区
:link: https://microsoft.github.io/ai-edu/index.html

微软人工智能教育与学习共建社区（Microsoft AI Education Community, 简称AI-Edu）是微软亚洲研究院（Microsoft Research Asia，简称MSRA）人工智能教育团队创立的人工智能开源社区。

本社区由基础教程、实践案例、实践项目三大模块构成，通过系统化的理论教程和丰富多样的实践案例，帮助学习者学习并掌握人工智能的知识，并锻炼在实际项目中的开发能力。
:::